clear
clear mata
clear matrix
set more off
set memory 800000
*set matsize 1100
*cd "\\data4\users10\csaborowski\My Documents\Intervention and UMP project\Brazil"
cd "I:\Brazil"

use data_2018_jmcb, clear
estimates clear


**** make additional transformations of intervention data (positive vs negative)  ******************************

tab year, gen(tdum)

gen spot_indic = 0
replace spot_indic = 1 if spot2>0

gen swaps_indic = 0 if swaps!=.
replace swaps_indic = 1 if swaps>0

gen swaps_posv = swaps*swaps_indic 
gen spot_posv = spot2*spot_indic 

gen spot_indic2 = 0
replace spot_indic2 = 1 if spot2<0

gen swaps_indic2 = 0 if swaps!=.
replace swaps_indic2 = 1 if swaps<0

gen swaps_negv = swaps*swaps_indic2 
gen spot_negv = spot2*spot_indic2 

tssmooth ma spot2_pos_ma  = spot_posv, window(5)
tssmooth ma swaps_pos_ma  = swaps_posv, window(5)
tssmooth ma swaps_neg_ma  = swaps_negv, window(5)
tssmooth ma spot2_neg_ma  = spot_negv, window(5)





***************************************************

**************** estimations*********



local controls  L_d_fx_rate L_d_vrp3m d_crb_comm_index L_d_crb_comm_index d_vix L_d_vix L_exp_depr_ma L_cds_ret
local instruments L_fx_dev_2W fx_rate_1Y d_selic_target_ma L_fx_vol_ma L_fx_trans_balance_ma L_spot2_ma L_swaps_ma	

outreg, clear(second)
outreg, clear(first)



* Repeat the baseline

ivreg2 d_fx_rate  `controls' tdum*  (swaps spot2   =  `instruments'   ), robust cue bw(5) endog(spot2 swaps) savefirst 

local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)


test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')" \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Real/$") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' swaps spot2  _cons) landscape plain 



*** 1. Add macro news: 

local controls  L_d_fx_rate L_d_vrp3m d_crb_comm_index L_d_crb_comm_index d_vix L_d_vix L_exp_depr_ma L_cds_ret infl_sup unemp_sup ip_sup 

ivreg2 d_fx_rate  `controls' tdum*  (swaps spot2   =  `instruments'   ), robust cue bw(5) endog(spot2 swaps) savefirst

local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)


test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')" \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Real/$") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' swaps spot2  _cons) landscape plain 




*** 2. Add EM news index: 

local controls  L_d_fx_rate L_d_vrp3m d_crb_comm_index L_d_crb_comm_index d_vix L_d_vix L_exp_depr_ma L_cds_ret citi_econ_surprise_em 

ivreg2 d_fx_rate  `controls' tdum*  (swaps spot2   =  `instruments'   ), robust cue bw(5) endog(spot2 swaps) savefirst

local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)

test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')"  \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Real/$") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' swaps spot2  _cons) landscape plain 


*** 3. Add LATAM news index: 

local controls  L_d_fx_rate L_d_vrp3m d_crb_comm_index L_d_crb_comm_index d_vix L_d_vix L_exp_depr_ma L_cds_ret citi_econ_surprise_latam 

ivreg2 d_fx_rate  `controls' tdum*  (swaps spot2   =  `instruments'   ), robust cue bw(5) endog(spot2 swaps)  savefirst

local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)


test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')"  \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')"  \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Real/$") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' swaps spot2  _cons) landscape plain 




*** 4. Add futher lags of FX rate: 

local controls  L_d_fx_rate L_d_vrp3m l2.d_fx_rate l3.d_fx_rate d_crb_comm_index L_d_crb_comm_index d_vix L_d_vix L_exp_depr_ma L_cds_ret

ivreg2 d_fx_rate  `controls' tdum*  (swaps spot2   =  `instruments'   ), robust cue bw(5) endog(spot2 swaps)  savefirst

local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)

test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')" \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Real/$") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' swaps spot2  _cons) landscape plain 




** 5. Add interest rate differential: 

local controls  L_d_fx_rate L_d_vrp3m d_crb_comm_index L_d_crb_comm_index d_vix L_d_vix L_exp_depr_ma L_cds_ret d_differ


ivreg2 d_fx_rate  `controls' tdum*  (swaps spot2   =  `instruments'   ), robust cue bw(5) endog(spot2 swaps)  savefirst

local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)


test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')" \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Real/$") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' swaps spot2  _cons) landscape plain 



** 6. Drop insignificant ones from the benchmark: 

local controls  L_d_fx_rate L_d_vrp3m d_crb_comm_index L_d_crb_comm_index L_d_vix L_exp_depr_ma L_cds_ret


ivreg2 d_fx_rate  `controls' tdum*  (swaps spot2   =  `instruments'   ), robust cue bw(5) endog(spot2 swaps)  savefirst

local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)


test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')"  \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Real/$") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' swaps spot2  _cons) landscape plain 


*** 7. Add day of the week effects: (not reported)
/*

local controls  L_d_fx_rate L_d_vrp3m d_crb_comm_index L_d_crb_comm_index d_vix L_d_vix L_exp_depr_ma L_cds_ret mon tue wed thu

ivreg2 d_fx_rate  `controls' tdum*  (swaps spot2   =  `instruments'   ), robust cue bw(5) endog(spot2 swaps)  savefirst

local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)


test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')" \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Real/$") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' swaps spot2  _cons) landscape plain 


*/

outreg using Table6_2018.doc, replay(second) replace  landscape  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)
