
clear
clear mata
clear matrix
set more off
set memory 800000
*set matsize 1100
*cd "\\data4\users10\csaborowski\My Documents\Intervention and UMP project\Brazil"
cd "I:\Brazil"

use data_2018_jmcb, clear
estimates clear



**** make additional transformations of intervention data (positive vs negative)  ******************************

tab year, gen(tdum)

gen spot_indic = 0
replace spot_indic = 1 if spot2>0

gen swaps_indic = 0 if swaps!=.
replace swaps_indic = 1 if swaps>0

gen swaps_posv = swaps*swaps_indic 
gen spot_posv = spot2*spot_indic 

gen spot_indic2 = 0
replace spot_indic2 = 1 if spot2<0

gen swaps_indic2 = 0 if swaps!=.
replace swaps_indic2 = 1 if swaps<0

gen swaps_negv = swaps*swaps_indic2 
gen spot_negv = spot2*spot_indic2 

tssmooth ma spot2_pos_ma  = spot_posv, window(5)
tssmooth ma swaps_pos_ma  = swaps_posv, window(5)
tssmooth ma swaps_neg_ma  = swaps_negv, window(5)
tssmooth ma spot2_neg_ma  = spot_negv, window(5)





***************************************************

**************** estimations*********


local controls  L_d_iv3mpch L_d_fx_rate d_crb_comm_index L_d_crb_comm_index d_vix L_d_vix 
local instruments L_fx_dev_2W fx_rate_1Y L_fx_vol_ma L_fx_trans_balance_ma d_selic_target_ma L_spot2_ma L_swaps_ma 




outreg, clear(second)
outreg, clear(first)



* 1. spot only

ivreg2 d_iv3mpch `controls' tdum* (spot2   =  `instruments'  ) if swaps!=., robust cue endog(spot2) bw(5) savefirst
mat f = e(first)
local F : display %5.1f f[4,1]
local p : display %5.2f f[7,1]
local SW : display %5.1f f[8,1]
local SWp : display %5.2f f[11,1]
local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local cd : display %5.0f e(cdf)
local arf : display %5.0f e(arf)
local arfp : display %5.2f e(arfp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)



outreg, addrows("Hansen J", "`j' (`jp')" \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Implied Volatility") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' spot2  _cons) landscape plain 
estimates restore _ivreg2_spot2
outreg, addrows("F test", "`F' (`p')"  \ "Kleibergen-Paap rk Wald F", "`Fstat'" \ "Sanderson-Windmeijer F test", "`SW' (`SWp')" \ "Kleibergen-Paap rk LM", "`k' (`kp')") merge(first)  replace se starlevels(10 5 1) varlabels title("First-Stage Regressions") ctitles("", "CUE Spot")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1) keep(`controls' `instruments'  _cons) landscape plain  


* 2. swaps only

ivreg2 d_iv3mpch `controls' tdum* (swaps   =  `instruments'  ) if swaps!=., robust cue bw(5) endog(swaps) savefirst

mat f = e(first)
local F : display %5.1f f[4,1]
local p : display %5.2f f[7,1]
local SW : display %5.1f f[8,1]
local SWp : display %5.2f f[11,1]
local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local cd : display %5.0f e(cdf)
local arf : display %5.0f e(arf)
local arfp : display %5.2f e(arfp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)



outreg, addrows("Hansen J", "`j' (`jp')"  \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Implied Volatility") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' swaps  _cons) landscape plain 
estimates restore _ivreg2_swaps
outreg, addrows("F test", "`F' (`p')"  \ "Kleibergen-Paap rk Wald F", "`Fstat'" \ "Sanderson-Windmeijer F test", "`SW' (`SWp')" \ "Kleibergen-Paap rk LM", "`k' (`kp')") merge(first)  replace se starlevels(10 5 1) varlabels title("First-Stage Regressions") ctitles("", "CUE Spot")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1) keep(`controls' `instruments'  _cons) landscape plain  


* 3. spot and swap:


ivreg2 d_iv3mpch `controls' tdum*  (swaps spot2   =  `instruments'   ), robust cue bw(5) endog(spot2 swaps) savefirst 


mat f = e(first)
local F : display %5.1f f[4,1]
local p : display %5.2f f[7,1]
local SW : display %5.1f f[8,1]
local SWp : display %5.2f f[11,1]
local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local cd : display %5.0f e(cdf)
local arf : display %5.0f e(arf)
local arfp : display %5.2f e(arfp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)


test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')" \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')"  \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Implied Volatility") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' spot2 swaps  _cons) landscape plain 
estimates restore _ivreg2_spot2
outreg, addrows("Sanderson-Windmeijer F test", "`SW' (`SWp')") merge(first)  replace se starlevels(10 5 1) varlabels title("First-Stage Regressions") ctitles("", "CUE Spot")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' `instruments'  _cons) landscape plain  
estimates restore _ivreg2_swaps
outreg, addrows("Sanderson-Windmeijer F test", "`SW2' (`SWp2')") merge(first)  replace se starlevels(10 5 1) varlabels title("First-Stage Regressions") ctitles("", "CUE Swap")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' `instruments'  _cons) landscape plain  

*** 4. OLS

reg d_iv3mpch `controls' tdum* swaps spot2 if swaps!=. & l.fx_trans_balance_ma!=., robust  
outreg, merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Percent Daily Change in Implied Volatility") ctitles("", "OLS")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls'  spot2 swaps _cons) landscape plain 


*********** 5.   Take longer sample: need to drop L_fx_trans_balance_ma and use diff_ndf_ma in instruments  ************************


local instruments L_fx_dev_2W fx_rate_1Y d_selic_target_ma l.diff_ndf_ma L_spot2_ma L_swaps_ma



ivreg2 d_iv3mpch `controls' tdum* (spot2 swaps   =  `instruments'  ), robust cue bw(5) endog(spot2 swaps) savefirst
mat f = e(first)
local F : display %5.1f f[4,1]
local p : display %5.2f f[7,1]
local SW : display %5.1f f[8,1]
local SWp : display %5.2f f[11,1]
local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local cd : display %5.0f e(cdf)
local arf : display %5.0f e(arf)
local arfp : display %5.2f e(arfp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)


test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wstat : display %5.2f r(chi2)
local Wstatp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')" \  "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test", "`Wstat' (`Wstatp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Implied Volatility") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' spot2 swaps  _cons) landscape plain 




** 6. Asymetric effects 

local controls  L_d_fx_rate L_d_iv3mpch d_crb_comm_index L_d_crb_comm_index d_vix L_d_vix
local instruments L_fx_dev_2W fx_rate_1Y L_fx_vol_ma L_fx_trans_balance_ma d_selic_target_ma L_spot2_ma L_swaps_ma  


* prepare instruments for interaction term

foreach var in `instruments' { 
gen `var'_spot = `var'*spot_indic
gen `var'_swaps = `var'*swaps_indic

}

local instruments_spot   L_fx_vol_ma_spot  d_selic_target_ma_spot L_fx_trans_balance_ma_spot 
local instruments_swaps  L_fx_vol_ma_swaps fx_rate_1Y_swaps L_spot2_ma_swaps

ivreg2 d_iv3mpch  `controls' tdum* (spot2 spot_posv swaps swaps_posv =  `instruments' l.spot2_pos_ma l.swaps_pos_ma `instruments_swaps' `instruments_spot'), robust cue bw(3) savefirst redundant(`instruments_swaps' `instruments_spot')

mat f = e(first)
local F : display %5.1f f[4,1]
local p : display %5.2f f[7,1]
local SW : display %5.1f f[8,1]
local SWp : display %5.2f f[11,1]
local Fstat : display %5.1f e(widstat)
local j : display %5.1f e(j)
local jp : display %5.2f e(jp)
local k : display %5.1f e(idstat)
local kp : display %5.2f e(idp)
local cd : display %5.0f e(cdf)
local arf : display %5.0f e(arf)
local arfp : display %5.2f e(arfp)
local sstat : display %5.1f e(sstat)
local sstatp : display %5.2f e(sstatp)
local cstat : display %5.1f e(archi2)
local cstatp : display %5.2f e(archi2p)

test (_b[swaps] - _b[spot2]=0)
display %5.1f r(chi2)
local Wshort : display %5.2f r(chi2)
local Wshortp : display %5.2f r(p)

test (_b[swaps]+_b[swaps_posv] - _b[spot2]- _b[spot_posv]=0)
display %5.1f r(chi2)
local Wlong : display %5.2f r(chi2)
local Wlongp : display %5.2f r(p)

outreg, addrows("Hansen J", "`j' (`jp')" \ "Stock-Wright LM S", "`sstat' (`sstatp')" \ "Endogeneity test", "`cstat' (`cstatp')" \ "Wald test - short US$", "`Wshort' (`Wshortp')" \ "Wald test - long US$", "`Wlong' (`Wlongp')") merge(second) replace se starlevels(10 5 1) varlabels title("Second-Stage Regressions", "Dependent Variable: Percent Daily Change in Implied Volatility") ctitles("", "CUE")  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)  keep(`controls' spot2 swaps spot_posv swaps_posv  _cons) landscape plain 



outreg using Table3_2018.doc, replay(second) replace  landscape  basefont(fs8) statfont(fs8) colwidth(23 9) starloc(1)


